@@ -2,7 +2,7 @@
 
 '''
 Advanced Interface Switcher
-2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+2010-2012(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 GSM interface object
 '''
 
@@ -64,15 +64,21 @@ class GSMInterface(AbstractInterface):
     return self.get_status()
 
   def process_signal_connected(self, value):
-    try: 
+    try:
+      strength = None
+      if self.get_config_value('show-signal-strength'):
+        strength = self.get_strength()
       return 1 + ['activation_pending', 'online'].index(str(value)), \
       self.get_mode(), \
-      self.get_strength()
+      strength
     except:
       return None, None, None
 
   def process_signal_strength(self, arg1, arg2):
-    return None, None, self.get_strength_value(arg1)
+    if self.get_config_value('show-signal-strength'):
+      return None, None, self.get_strength_value(arg1)
+    else:
+      return None, None, None
 
   def get_status(self):
     try:
