@@ -2,7 +2,7 @@
 
 '''
 Advanced Interface Switcher
-2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+2010-2012(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 WLAN interface object
 '''
 
@@ -25,6 +25,7 @@ class WLANInterface(AbstractInterface):
   wifi_icdui_iface = 'com.nokia.icd_ui'
 
   def pre_init(self):
+    self.__strength_timeout = None
     self.autooff = None
     self.has_be = get_shell_command_output('ls /lib/modules/$(uname -r) | grep -m 1 wl1251') != ''
     self.state = {'name': 'WLAN',
@@ -83,12 +84,14 @@ class WLANInterface(AbstractInterface):
         if self.autooff:
           gobject.source_remove(self.autooff)
           self.autooff = None
-        gobject.timeout_add(1000, self.get_strength)
+        if self.get_config_value('show-signal-strength'):
+          self.__strength_timeout = gobject.timeout_add(1000, self.get_strength)
         return 2, 0, None
       elif args[7] == 0 and self.state['value'] != 0:
         autooff = int(self.get_config_value('disconnected-timeout'))
         if autooff > 0 and self.state['value'] == 2:
           self.autooff = gobject.timeout_add(autooff*1000, self.turn_off)
+          gobject.source_remove(self.__strength_timeout)
         return 1, 0, None
       else:
         return self.state['value'], 0, None
@@ -149,9 +152,9 @@ class WLANInterface(AbstractInterface):
       self.reinit_interface('ICD')
 
   def get_strength(self):
-    if self.state['value'] == 2:
+    if self.state['value'] == 2 and self.get_config_value('show-signal-strength'):
       self.get_interface('ICD').statistics_req()
-      gobject.timeout_add(5000, self.get_strength)
+      self.__strength_timeout = gobject.timeout_add(5000, self.get_strength)
     return False
 
   def turn_mode(self, mode):
